@@ -1,8 +1,10 @@
 package Helios;
 
 use 5.008000;
+use strict;
+use warnings;
 
-our $VERSION = '2.80';
+our $VERSION = '2.81';
 
 # 2011-12-07: Added Andrew Johnson copyright notices.
 # 2012-01-04: Reset all line length limits to 80.  
@@ -10,6 +12,8 @@ our $VERSION = '2.80';
 # [LH] 2012-07-16:  Added Logical Helion, LLC and Six Apart Ltd copyright 
 # notices.
 # [LH] [2014-02-28]: Updated copyright info.
+# [LH] [2014-08-10]: Added strict and warnings pragmas to satisfy certain 
+# CPAN testing systems.
 
 =head1 NAME
 
